@@ -2,7 +2,7 @@
 #
 # raccess4vbox3.tcl
 #
-# $Id: raccess4vbox3.tcl,v 1.4 2001/09/23 12:16:44 pape Exp $
+# $Id: raccess4vbox3.tcl,v 1.5 2002/03/02 14:50:52 pape Exp $
 #
 #    Copyright (C) 2000  G. Pape <pape@smarden.org>
 #
@@ -28,6 +28,12 @@ proc repeat { } {
     return "REPEAT"
 }
 
+###############################################################################
+# hangup
+proc hangup { } {
+    return "HANGUP"
+}
+
 ###############################################################################
 # skip
 proc skip { } {
@@ -663,7 +669,7 @@ proc raccess_run { what } {
 		    set tuning(actualmode) $m
 		    raccess_log D \
 			    "run: run: setting tuning(actualmode) = $tuning(actualmode)"
-		    global ${m}_run ${m}_dtmf ${m}_dtmf_eval
+		    global ${m}_run ${m}_dtmf ${m}_dtmf_eval ${m}_events
 		    
 		    # init dtmf
 		    vbox_breaklist c
@@ -712,9 +718,13 @@ proc raccess_run { what } {
 				    break
 				}
 			    }
-				}
+			}
 			incr vdo -1
 		    }
+		    if { [ info exists ${m}_events(quit) ] } {
+			raccess_log D "run: run: ${m}_events(quit) exists. hanging up"
+			return "HANGUP"
+		    }
 		}
 		raccess_run_restore
 		raccess_log D "run: run: done: exiting, return OK"
